schemetools.SchemeVector
========================

.. inheritance-diagram:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector
   :private-bases:

.. autoclass:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.force_quotes

    Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. autoattribute:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.lilypond_format

    Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. autoattribute:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__eq__

    Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__repr__

    Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. automethod:: abjad.tools.schemetools.SchemeVector.SchemeVector.SchemeVector.__str__

    Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`
